import React from 'react';
import PropTypes from 'prop-types';
import { DefaultTheme } from 'styled-components';
import ReactModal from 'react-modal';
import { RootNode } from "../../util/useRootNode";
import noop from "../../util/noop";
export type ModalTheme = DefaultTheme & {
    modalHeight: number;
    windowHeight: number;
    portalClassName: string;
};
type HTMLRef = React.ForwardedRef<HTMLElement> | undefined;
type BackdropValue = boolean | 'static';
declare const modalSize: {
    readonly small: "300px";
    readonly medium: "600px";
    readonly large: "900px";
};
export type ModalSize = keyof typeof modalSize;
export type ModalProps = Override<Omit<ReactModal.Props, 'isOpen'>, {
    show?: boolean;
    size?: ModalSize;
    parentSelector?: () => RootNode;
    className?: string;
    animation?: boolean;
    backdrop?: BackdropValue;
    children?: React.ReactNode;
    escapeExits?: boolean;
    onEnter?: () => void;
    onExit?: () => void;
    onHide?: () => void;
    overlayRef?: HTMLRef;
    contentRef?: HTMLRef;
}>;
declare function Modal({ animation, backdrop, children, escapeExits, onEnter, onExit, onHide, show, size, parentSelector, className, overlayRef, contentRef, ...other }: ModalProps): React.JSX.Element;
declare namespace Modal {
    var propTypes: {
        isOpen: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        overlayClassName: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        closeTimeoutMS: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        aria: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        onRequestClose: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        onAfterOpen: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        onAfterClose: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        shouldCloseOnEsc: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
        /** Open and close the Modal with transitions. */
        animation: PropTypes.Requireable<boolean>;
        /**
         * Include a backdrop component. Specify 'static' for a backdrop that doesn't
         * trigger an "onHide" when clicked.
         */
        backdrop: PropTypes.Requireable<string | boolean>;
        /**
         * Usually contains a Modal.Header, Modal.Body, and Modal.Footer
         * but can contain any content
         */
        children: PropTypes.Requireable<any>;
        /** Set whether the Escape key exits the modal */
        escapeExits: PropTypes.Requireable<boolean>;
        /** Callback fired when the Modal transitions in */
        onEnter: PropTypes.Requireable<(...args: any[]) => any>;
        /** Callback fired when the modal transitions out */
        onExit: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * A callback fired when the header closeButton or non-static backdrop is
         * clicked. Required if either are specified.
         */
        onHide: PropTypes.Requireable<(...args: any[]) => any>;
        /** When `true` The modal will show itself. */
        show: PropTypes.Requireable<boolean>;
        /** Sets the size of the modal */
        size: PropTypes.Requireable<string>;
        /** Selects the parent */
        parentSelector: PropTypes.Requireable<(...args: any[]) => any>;
        className: PropTypes.Requireable<string>;
        overlayRef: PropTypes.Requireable<NonNullable<((...args: any[]) => any) | PropTypes.InferProps<{
            current: PropTypes.Requireable<any>;
        }> | null | undefined>>;
        contentRef: PropTypes.Requireable<NonNullable<((...args: any[]) => any) | PropTypes.InferProps<{
            current: PropTypes.Requireable<any>;
        }> | null | undefined>>;
        data?: any;
        style?: any;
        id?: any;
        role?: any;
        portalClassName?: any;
        bodyOpenClassName?: any;
        htmlOpenClassName?: any;
        appElement?: any;
        ariaHideApp?: any;
        shouldFocusAfterRender?: any;
        shouldCloseOnOverlayClick?: any;
        shouldReturnFocusAfterClose?: any;
        preventScroll?: any;
        contentLabel?: any;
        overlayElement?: any;
        contentElement?: any;
        testId?: any;
    };
    var defaultProps: {
        animation: boolean;
        backdrop: boolean;
        escapeExits: boolean;
        onEnter: typeof noop;
        onExit: typeof noop;
        onHide: typeof noop;
        show: boolean;
        size: string;
        children: undefined;
        parentSelector: null;
        className: null;
        overlayRef: null;
        contentRef: null;
    };
    var Header: typeof import("./ModalHeader").default;
    var Body: import("styled-components").StyledComponent<"div", DefaultTheme, {}, never>;
    var Footer: import("styled-components").StyledComponent<"div", DefaultTheme, {}, never>;
}
export declare const propTypes: {
    isOpen: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    overlayClassName: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    closeTimeoutMS: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    aria: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    onRequestClose: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    onAfterOpen: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    onAfterClose: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    shouldCloseOnEsc: (props: Record<string, unknown>, propName: string, componentName: string) => Error | undefined;
    /** Open and close the Modal with transitions. */
    animation: PropTypes.Requireable<boolean>;
    /**
     * Include a backdrop component. Specify 'static' for a backdrop that doesn't
     * trigger an "onHide" when clicked.
     */
    backdrop: PropTypes.Requireable<string | boolean>;
    /**
     * Usually contains a Modal.Header, Modal.Body, and Modal.Footer
     * but can contain any content
     */
    children: PropTypes.Requireable<any>;
    /** Set whether the Escape key exits the modal */
    escapeExits: PropTypes.Requireable<boolean>;
    /** Callback fired when the Modal transitions in */
    onEnter: PropTypes.Requireable<(...args: any[]) => any>;
    /** Callback fired when the modal transitions out */
    onExit: PropTypes.Requireable<(...args: any[]) => any>;
    /**
     * A callback fired when the header closeButton or non-static backdrop is
     * clicked. Required if either are specified.
     */
    onHide: PropTypes.Requireable<(...args: any[]) => any>;
    /** When `true` The modal will show itself. */
    show: PropTypes.Requireable<boolean>;
    /** Sets the size of the modal */
    size: PropTypes.Requireable<string>;
    /** Selects the parent */
    parentSelector: PropTypes.Requireable<(...args: any[]) => any>;
    className: PropTypes.Requireable<string>;
    overlayRef: PropTypes.Requireable<NonNullable<((...args: any[]) => any) | PropTypes.InferProps<{
        current: PropTypes.Requireable<any>;
    }> | null | undefined>>;
    contentRef: PropTypes.Requireable<NonNullable<((...args: any[]) => any) | PropTypes.InferProps<{
        current: PropTypes.Requireable<any>;
    }> | null | undefined>>;
    data?: any;
    style?: any;
    id?: any;
    role?: any;
    portalClassName?: any;
    bodyOpenClassName?: any;
    htmlOpenClassName?: any;
    appElement?: any;
    ariaHideApp?: any;
    shouldFocusAfterRender?: any;
    shouldCloseOnOverlayClick?: any;
    shouldReturnFocusAfterClose?: any;
    preventScroll?: any;
    contentLabel?: any;
    overlayElement?: any;
    contentElement?: any;
    testId?: any;
};
export declare const defaultProps: {
    animation: boolean;
    backdrop: boolean;
    escapeExits: boolean;
    onEnter: typeof noop;
    onExit: typeof noop;
    onHide: typeof noop;
    show: boolean;
    size: string;
    children: undefined;
    parentSelector: null;
    className: null;
    overlayRef: null;
    contentRef: null;
};
export default Modal;
