import React from 'react';
import * as CSS from 'csstype';
import { DefaultTheme } from 'styled-components';
import { ValidationStyleType } from "../../../../../../../shared/types/dist/src";
import { HTMLInputProps } from "../../util/htmlProps";
import { RadioGroupContextShape } from "./RadioGroupContext";
export declare const RadioDisplayWrapper: import("styled-components").StyledComponent<"div", DefaultTheme, {}, never>;
export declare const RadioDisplay: import("styled-components").StyledComponent<"span", DefaultTheme, {}, never>;
export declare const RadioInput: import("styled-components").StyledComponent<"input", DefaultTheme, {
    fill: CSS.Property.BackgroundColor;
}, never>;
export type RadioButtonProps = HTMLInputProps & {
    displayClassName?: string;
};
export declare function getCheckedProps(radioProps: RadioButtonProps, contextProps: RadioGroupContextShape<boolean>): {
    onChange: React.ChangeEventHandler<HTMLInputElement>;
    checked: boolean;
    defaultChecked: undefined;
} | {
    defaultChecked: boolean;
    checked: undefined;
    onChange?: undefined;
};
export interface ValidationSelectionColors {
    fill: CSS.Property.BackgroundColor;
    hover: CSS.Property.BackgroundColor;
}
export declare const getValidationSelectionColors: (theme: DefaultTheme, validationState: ValidationStyleType, checked?: boolean) => ValidationSelectionColors;
export declare const RadioButton: React.ForwardRefExoticComponent<Omit<Omit<React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "key">, "ref"> & {
    displayClassName?: string | undefined;
} & React.RefAttributes<HTMLInputElement>>;
export declare const propTypes: {
    /** supports styled-component usage, applies to the wrapping Label */
    className: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    /** applies to the display wrapper */
    displayClassName: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    form: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    slot: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    style: import("prop-types").Requireable<React.CSSProperties | undefined> | import("prop-types").Validator<React.CSSProperties | undefined>;
    title: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    pattern: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    type: import("prop-types").Requireable<React.HTMLInputTypeAttribute | undefined> | import("prop-types").Validator<React.HTMLInputTypeAttribute | undefined>;
    name: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    suppressHydrationWarning: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    color: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    height: import("prop-types").Requireable<string | number | undefined> | import("prop-types").Validator<string | number | undefined>;
    id: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    lang: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    max: import("prop-types").Requireable<string | number | undefined> | import("prop-types").Validator<string | number | undefined>;
    min: import("prop-types").Requireable<string | number | undefined> | import("prop-types").Validator<string | number | undefined>;
    width: import("prop-types").Requireable<string | number | undefined> | import("prop-types").Validator<string | number | undefined>;
    role: import("prop-types").Requireable<React.AriaRole | undefined> | import("prop-types").Validator<React.AriaRole | undefined>;
    tabIndex: import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-activedescendant": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-atomic": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-autocomplete": import("prop-types").Requireable<"list" | "none" | "inline" | "both" | undefined> | import("prop-types").Validator<"list" | "none" | "inline" | "both" | undefined>;
    "aria-braillelabel": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-brailleroledescription": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-busy": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-checked": import("prop-types").Requireable<boolean | "true" | "false" | "mixed" | undefined> | import("prop-types").Validator<boolean | "true" | "false" | "mixed" | undefined>;
    "aria-colcount": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-colindex": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-colindextext": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-colspan": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-controls": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-current": import("prop-types").Requireable<boolean | "time" | "true" | "false" | "page" | "step" | "location" | "date" | undefined> | import("prop-types").Validator<boolean | "time" | "true" | "false" | "page" | "step" | "location" | "date" | undefined>;
    "aria-describedby": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-description": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-details": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-disabled": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-dropeffect": import("prop-types").Requireable<"link" | "none" | "copy" | "execute" | "move" | "popup" | undefined> | import("prop-types").Validator<"link" | "none" | "copy" | "execute" | "move" | "popup" | undefined>;
    "aria-errormessage": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-expanded": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-flowto": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-grabbed": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-haspopup": import("prop-types").Requireable<boolean | "dialog" | "menu" | "grid" | "listbox" | "tree" | "true" | "false" | undefined> | import("prop-types").Validator<boolean | "dialog" | "menu" | "grid" | "listbox" | "tree" | "true" | "false" | undefined>;
    "aria-hidden": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-invalid": import("prop-types").Requireable<boolean | "true" | "false" | "grammar" | "spelling" | undefined> | import("prop-types").Validator<boolean | "true" | "false" | "grammar" | "spelling" | undefined>;
    "aria-keyshortcuts": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-label": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-labelledby": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-level": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-live": import("prop-types").Requireable<"off" | "assertive" | "polite" | undefined> | import("prop-types").Validator<"off" | "assertive" | "polite" | undefined>;
    "aria-modal": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-multiline": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-multiselectable": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-orientation": import("prop-types").Requireable<"horizontal" | "vertical" | undefined> | import("prop-types").Validator<"horizontal" | "vertical" | undefined>;
    "aria-owns": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-placeholder": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-posinset": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-pressed": import("prop-types").Requireable<boolean | "true" | "false" | "mixed" | undefined> | import("prop-types").Validator<boolean | "true" | "false" | "mixed" | undefined>;
    "aria-readonly": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-relevant": import("prop-types").Requireable<"text" | "additions" | "additions removals" | "additions text" | "all" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined> | import("prop-types").Validator<"text" | "additions" | "additions removals" | "additions text" | "all" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined>;
    "aria-required": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-roledescription": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-rowcount": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-rowindex": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-rowindextext": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    "aria-rowspan": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-selected": import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    "aria-setsize": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-sort": import("prop-types").Requireable<"other" | "none" | "ascending" | "descending" | undefined> | import("prop-types").Validator<"other" | "none" | "ascending" | "descending" | undefined>;
    "aria-valuemax": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-valuemin": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-valuenow": import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    "aria-valuetext": import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    children: import("prop-types").Requireable<React.ReactNode> | import("prop-types").Validator<React.ReactNode>;
    dangerouslySetInnerHTML: import("prop-types").Requireable<{
        __html: string | TrustedHTML;
    } | undefined> | import("prop-types").Validator<{
        __html: string | TrustedHTML;
    } | undefined>;
    onCopy: import("prop-types").Requireable<React.ClipboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ClipboardEventHandler<HTMLInputElement> | undefined>;
    onCopyCapture: import("prop-types").Requireable<React.ClipboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ClipboardEventHandler<HTMLInputElement> | undefined>;
    onCut: import("prop-types").Requireable<React.ClipboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ClipboardEventHandler<HTMLInputElement> | undefined>;
    onCutCapture: import("prop-types").Requireable<React.ClipboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ClipboardEventHandler<HTMLInputElement> | undefined>;
    onPaste: import("prop-types").Requireable<React.ClipboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ClipboardEventHandler<HTMLInputElement> | undefined>;
    onPasteCapture: import("prop-types").Requireable<React.ClipboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ClipboardEventHandler<HTMLInputElement> | undefined>;
    onCompositionEnd: import("prop-types").Requireable<React.CompositionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.CompositionEventHandler<HTMLInputElement> | undefined>;
    onCompositionEndCapture: import("prop-types").Requireable<React.CompositionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.CompositionEventHandler<HTMLInputElement> | undefined>;
    onCompositionStart: import("prop-types").Requireable<React.CompositionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.CompositionEventHandler<HTMLInputElement> | undefined>;
    onCompositionStartCapture: import("prop-types").Requireable<React.CompositionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.CompositionEventHandler<HTMLInputElement> | undefined>;
    onCompositionUpdate: import("prop-types").Requireable<React.CompositionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.CompositionEventHandler<HTMLInputElement> | undefined>;
    onCompositionUpdateCapture: import("prop-types").Requireable<React.CompositionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.CompositionEventHandler<HTMLInputElement> | undefined>;
    onFocus: import("prop-types").Requireable<React.FocusEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FocusEventHandler<HTMLInputElement> | undefined>;
    onFocusCapture: import("prop-types").Requireable<React.FocusEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FocusEventHandler<HTMLInputElement> | undefined>;
    onBlur: import("prop-types").Requireable<React.FocusEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FocusEventHandler<HTMLInputElement> | undefined>;
    onBlurCapture: import("prop-types").Requireable<React.FocusEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FocusEventHandler<HTMLInputElement> | undefined>;
    onChange: import("prop-types").Requireable<React.ChangeEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ChangeEventHandler<HTMLInputElement> | undefined>;
    onChangeCapture: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onBeforeInput: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onBeforeInputCapture: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onInput: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onInputCapture: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onReset: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onResetCapture: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onSubmit: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onSubmitCapture: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onInvalid: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onInvalidCapture: import("prop-types").Requireable<React.FormEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.FormEventHandler<HTMLInputElement> | undefined>;
    onLoad: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onError: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onErrorCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onKeyDown: import("prop-types").Requireable<React.KeyboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.KeyboardEventHandler<HTMLInputElement> | undefined>;
    onKeyDownCapture: import("prop-types").Requireable<React.KeyboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.KeyboardEventHandler<HTMLInputElement> | undefined>;
    onKeyPress: import("prop-types").Requireable<React.KeyboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.KeyboardEventHandler<HTMLInputElement> | undefined>;
    onKeyPressCapture: import("prop-types").Requireable<React.KeyboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.KeyboardEventHandler<HTMLInputElement> | undefined>;
    onKeyUp: import("prop-types").Requireable<React.KeyboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.KeyboardEventHandler<HTMLInputElement> | undefined>;
    onKeyUpCapture: import("prop-types").Requireable<React.KeyboardEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.KeyboardEventHandler<HTMLInputElement> | undefined>;
    onAbort: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onAbortCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onCanPlay: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onCanPlayCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onCanPlayThrough: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onCanPlayThroughCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onDurationChange: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onDurationChangeCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onEmptied: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onEmptiedCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onEncrypted: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onEncryptedCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onEnded: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onEndedCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadedData: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadedDataCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadedMetadata: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadedMetadataCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadStart: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onLoadStartCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onPause: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onPauseCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onPlay: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onPlayCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onPlaying: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onPlayingCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onProgress: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onProgressCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onRateChange: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onRateChangeCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onResize: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onResizeCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSeeked: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSeekedCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSeeking: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSeekingCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onStalled: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onStalledCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSuspend: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSuspendCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onTimeUpdate: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onTimeUpdateCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onVolumeChange: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onVolumeChangeCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onWaiting: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onWaitingCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onAuxClick: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onAuxClickCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onClick: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onClickCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onContextMenu: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onContextMenuCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onDoubleClick: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onDoubleClickCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onDrag: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragEnd: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragEndCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragEnter: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragEnterCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragExit: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragExitCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragLeave: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragLeaveCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragOver: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragOverCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragStart: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDragStartCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDrop: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onDropCapture: import("prop-types").Requireable<React.DragEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.DragEventHandler<HTMLInputElement> | undefined>;
    onMouseDown: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseDownCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseEnter: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseLeave: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseMove: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseMoveCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseOut: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseOutCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseOver: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseOverCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseUp: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onMouseUpCapture: import("prop-types").Requireable<React.MouseEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.MouseEventHandler<HTMLInputElement> | undefined>;
    onSelect: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onSelectCapture: import("prop-types").Requireable<React.ReactEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.ReactEventHandler<HTMLInputElement> | undefined>;
    onTouchCancel: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchCancelCapture: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchEnd: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchEndCapture: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchMove: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchMoveCapture: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchStart: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onTouchStartCapture: import("prop-types").Requireable<React.TouchEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TouchEventHandler<HTMLInputElement> | undefined>;
    onPointerDown: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerDownCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerMove: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerMoveCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerUp: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerUpCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerCancel: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerCancelCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerEnter: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerEnterCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerLeave: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerLeaveCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerOver: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerOverCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerOut: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onPointerOutCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onGotPointerCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onGotPointerCaptureCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onLostPointerCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onLostPointerCaptureCapture: import("prop-types").Requireable<React.PointerEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.PointerEventHandler<HTMLInputElement> | undefined>;
    onScroll: import("prop-types").Requireable<React.UIEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.UIEventHandler<HTMLInputElement> | undefined>;
    onScrollCapture: import("prop-types").Requireable<React.UIEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.UIEventHandler<HTMLInputElement> | undefined>;
    onWheel: import("prop-types").Requireable<React.WheelEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.WheelEventHandler<HTMLInputElement> | undefined>;
    onWheelCapture: import("prop-types").Requireable<React.WheelEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.WheelEventHandler<HTMLInputElement> | undefined>;
    onAnimationStart: import("prop-types").Requireable<React.AnimationEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.AnimationEventHandler<HTMLInputElement> | undefined>;
    onAnimationStartCapture: import("prop-types").Requireable<React.AnimationEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.AnimationEventHandler<HTMLInputElement> | undefined>;
    onAnimationEnd: import("prop-types").Requireable<React.AnimationEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.AnimationEventHandler<HTMLInputElement> | undefined>;
    onAnimationEndCapture: import("prop-types").Requireable<React.AnimationEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.AnimationEventHandler<HTMLInputElement> | undefined>;
    onAnimationIteration: import("prop-types").Requireable<React.AnimationEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.AnimationEventHandler<HTMLInputElement> | undefined>;
    onAnimationIterationCapture: import("prop-types").Requireable<React.AnimationEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.AnimationEventHandler<HTMLInputElement> | undefined>;
    onTransitionEnd: import("prop-types").Requireable<React.TransitionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TransitionEventHandler<HTMLInputElement> | undefined>;
    onTransitionEndCapture: import("prop-types").Requireable<React.TransitionEventHandler<HTMLInputElement> | undefined> | import("prop-types").Validator<React.TransitionEventHandler<HTMLInputElement> | undefined>;
    css: import("prop-types").Requireable<import("styled-components").CSSProp | undefined> | import("prop-types").Validator<import("styled-components").CSSProp | undefined>;
    list: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    step: import("prop-types").Requireable<string | number | undefined> | import("prop-types").Validator<string | number | undefined>;
    defaultChecked: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    defaultValue: import("prop-types").Requireable<string | number | readonly string[] | undefined> | import("prop-types").Validator<string | number | readonly string[] | undefined>;
    suppressContentEditableWarning: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    accessKey: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    autoFocus: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    contentEditable: import("prop-types").Requireable<"inherit" | (boolean | "true" | "false") | "plaintext-only" | undefined> | import("prop-types").Validator<"inherit" | (boolean | "true" | "false") | "plaintext-only" | undefined>;
    contextMenu: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    dir: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    draggable: import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    hidden: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    nonce: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    spellCheck: import("prop-types").Requireable<(boolean | "true" | "false") | undefined> | import("prop-types").Validator<(boolean | "true" | "false") | undefined>;
    translate: import("prop-types").Requireable<"no" | "yes" | undefined> | import("prop-types").Validator<"no" | "yes" | undefined>;
    radioGroup: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    about: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    content: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    datatype: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    inlist: import("prop-types").Validator<any> | import("prop-types").Requireable<any>;
    prefix: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    property: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    rel: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    resource: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    rev: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    typeof: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    vocab: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    autoCapitalize: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    autoCorrect: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    autoSave: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    itemProp: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    itemScope: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    itemType: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    itemID: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    itemRef: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    results: import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    security: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    unselectable: import("prop-types").Requireable<"off" | "on" | undefined> | import("prop-types").Validator<"off" | "on" | undefined>;
    inputMode: import("prop-types").Requireable<"search" | "text" | "none" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined> | import("prop-types").Validator<"search" | "text" | "none" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined>;
    is: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    size: import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    alt: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    src: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    value: import("prop-types").Requireable<string | number | readonly string[] | undefined> | import("prop-types").Validator<string | number | readonly string[] | undefined>;
    accept: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    autoComplete: import("prop-types").Requireable<React.HTMLInputAutoCompleteAttribute | undefined> | import("prop-types").Validator<React.HTMLInputAutoCompleteAttribute | undefined>;
    capture: import("prop-types").Requireable<boolean | "user" | "environment" | undefined> | import("prop-types").Validator<boolean | "user" | "environment" | undefined>;
    checked: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    disabled: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    enterKeyHint: import("prop-types").Requireable<"search" | "enter" | "done" | "go" | "next" | "previous" | "send" | undefined> | import("prop-types").Validator<"search" | "enter" | "done" | "go" | "next" | "previous" | "send" | undefined>;
    formAction: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    formEncType: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    formMethod: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    formNoValidate: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    formTarget: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    maxLength: import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    minLength: import("prop-types").Requireable<number | undefined> | import("prop-types").Validator<number | undefined>;
    multiple: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    placeholder: import("prop-types").Requireable<string | undefined> | import("prop-types").Validator<string | undefined>;
    readOnly: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
    required: import("prop-types").Requireable<boolean | undefined> | import("prop-types").Validator<boolean | undefined>;
};
export default RadioButton;
